/**
 * Utils - Filters
 */
import type { Filters, FiltersFunctions } from './filtersTypes';
/**
 * Store filter callbacks by name
 *
 * @type {import('./filtersTypes').FiltersFunctions}
 */
declare let filters: FiltersFunctions;
/**
 * Function - add filter to filters object
 *
 * @param {string} name
 * @param {function} filter
 * @return {boolean}
 */
declare const addFilter: <T extends keyof Filters>(name: T, filter: Filters[T]) => boolean;
/**
 * Function - remove filter from filters object
 *
 * @param {string} name
 * @param {function} filter
 * @return {boolean}
 */
declare const removeFilter: <T extends keyof Filters>(name: T, filter: Filters[T]) => boolean;
/**
 * Function - update value from callback return values
 *
 * @param {string} name
 * @param {*} value
 * @param {*} [args]
 * @return {Promise<*>}
 */
declare const applyFilters: <T, U>(name: string, value: T, args?: U) => Promise<T>;
/**
 * Function - empty filters object
 *
 * @return {void}
 */
declare const resetFilters: () => void;
/**
 * Function - fill filters object
 *
 * @param {import('./filtersTypes').Filters} args
 * @return {boolean}
 */
declare const setFilters: (args: Partial<Filters>) => boolean;
export { filters, addFilter, removeFilter, applyFilters, resetFilters, setFilters };
