"use strict";
/**
 * Utils - Get Content Type Labels
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getContentTypeLabels = void 0;
const config_1 = require("../../config/config");
const isObject_1 = require("../isObject/isObject");
const isString_1 = require("../isString/isString");
const normalizeContentType_1 = require("../normalizeContentType/normalizeContentType");
/**
 * Function - singular and plural labels by content/taxonomy type
 *
 * @param {string} contentType
 * @param {string} [casing]
 * @param {import('../../global/globalTypes').Taxonomy} [taxonomy]
 * @return {import('./getContentTypeLabelsTypes').ContentTypeLabels}
 */
const getContentTypeLabels = (contentType = '', casing = '', taxonomy) => {
    let singular = 'Post';
    let plural = 'Posts';
    let type = contentType;
    if ((0, isObject_1.isObjectStrict)(taxonomy)) {
        type = taxonomy.contentType;
    }
    if ((0, isString_1.isStringStrict)(type)) {
        type = (0, normalizeContentType_1.normalizeContentType)(type);
        const s = config_1.config.archiveMeta[type].singular;
        const p = config_1.config.archiveMeta[type].plural;
        singular = (0, isString_1.isStringStrict)(s) ? s : '';
        plural = (0, isString_1.isStringStrict)(p) ? p : '';
    }
    if (casing === 'lower') {
        singular = singular.toLowerCase();
        plural = plural.toLowerCase();
    }
    if (casing === 'upper') {
        singular = singular.toUpperCase();
        plural = plural.toUpperCase();
    }
    return {
        singular,
        plural
    };
};
exports.getContentTypeLabels = getContentTypeLabels;
