"use strict";
/**
 * Utils - Get Excerpt
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getExcerpt = void 0;
const isObject_1 = require("../isObject/isObject");
const isString_1 = require("../isString/isString");
const getObjectKeys_1 = require("../getObjectKeys/getObjectKeys");
const shortcodes_1 = require("../shortcodes/shortcodes");
/**
 * Function - get words from object or array of content
 *
 * @private
 * @param {import('./getExcerptTypes').ExcerptContentWordArgs} args
 * @return {string[]}
 */
const _getContentWords = (args) => {
    const { content, prop, limit = 25 } = args;
    let { _words = [] } = args;
    const max = limit + 1;
    const wordsLen = _words.length;
    if ((0, isObject_1.isObject)(content) && wordsLen < max) {
        const addMax = max - wordsLen;
        (0, getObjectKeys_1.getObjectKeys)(content).forEach((key) => {
            const value = content[key];
            if (key === prop && (0, isString_1.isStringStrict)(value)) {
                const val = (0, shortcodes_1.stripShortcodes)(value);
                if ((0, isString_1.isStringStrict)(val)) {
                    let valArr = val.split(' ');
                    const valArrLen = valArr.length;
                    if (valArrLen > addMax) {
                        valArr = valArr.splice(0, addMax);
                    }
                    _words = _words.concat(valArr);
                }
            }
            if ((0, isObject_1.isObject)(value)) {
                _words = _getContentWords({
                    content: value,
                    prop,
                    limit,
                    _words
                });
            }
        });
    }
    return _words;
};
/**
 * Function - get exercept from content and limit by words
 *
 * @param {import('./getExcerptTypes').ExcerptArgs} args
 * @return {string}
 */
const getExcerpt = (args) => {
    const { excerpt = '', content = undefined, prop = 'content', limit = 25, limitExcerpt = false, more = '&hellip;' } = (0, isObject_1.isObjectStrict)(args) ? args : {};
    let output = '';
    if ((0, isString_1.isStringStrict)(excerpt)) {
        output = excerpt;
        if (limitExcerpt) {
            let excerptArr = excerpt.split(' ');
            const excerptLen = excerptArr.length;
            if (excerptLen > limit) {
                excerptArr = excerptArr.splice(0, limit);
                output = `${excerptArr.join(' ')}${more}`;
            }
        }
    }
    else {
        const words = _getContentWords({
            content,
            prop,
            limit
        });
        const wordsLen = words.length;
        if (wordsLen > 0) {
            if (wordsLen > limit && more !== '') {
                words.pop();
            }
            output = `${words.join(' ')}${wordsLen > limit ? more : ''}`;
        }
    }
    return output;
};
exports.getExcerpt = getExcerpt;
