"use strict";
/**
 * Utils - Get Json
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getJsonFile = exports.getJson = void 0;
/* Imports */
const isObject_1 = require("../isObject/isObject");
/**
 * Function - check and return valid JSON or fallback
 *
 * @param {string} value
 * @return {object|undefined}
 */
const getJson = (value) => {
    try {
        const obj = JSON.parse(value);
        if ((0, isObject_1.isObject)(obj)) {
            return obj;
        }
    }
    catch {
        return undefined;
    }
    return undefined;
};
exports.getJson = getJson;
/**
 * Function - import json file and return contents if object
 *
 * @param {string} path
 * @return {Promise<object|undefined>}
 */
const getJsonFile = async (path) => {
    try {
        const { default: obj } = await Promise.resolve(`${path}`).then(s => require(s)); // Removed assert json as not all exports are esnext
        if ((0, isObject_1.isObject)(obj)) {
            return obj;
        }
    }
    catch {
        return undefined;
    }
    return undefined;
};
exports.getJsonFile = getJsonFile;
