"use strict";
/**
 * Utils - Get Share Links
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getShareLinks = void 0;
const isString_1 = require("../isString/isString");
const isArray_1 = require("../isArray/isArray");
/**
 * Start of share links by platform
 *
 * @type {import('./getShareLinksTypes').ShareLinks}
 */
const _shareLinks = {
    Facebook: 'https://www.facebook.com/sharer.php?u=',
    X: 'https://twitter.com/intent/tweet?url=',
    LinkedIn: 'https://www.linkedin.com/shareArticle?url=',
    Pinterest: 'https://pinterest.com/pin/create/button/?url=',
    Reddit: 'https://reddit.com/submit?url=',
    Email: ''
};
/**
 * Function - get social share links
 *
 * @param {string} url
 * @param {string[]} platforms
 * @return {import('./getShareLinksTypes').ShareLinksReturn[]}
 */
const getShareLinks = (url, platforms, title) => {
    if (!(0, isString_1.isStringStrict)(url) || !(0, isArray_1.isArrayStrict)(platforms)) {
        return [];
    }
    return platforms.map((platform) => {
        const platformLink = _shareLinks[platform];
        let link = platformLink !== undefined ? `${platformLink}${url}` : '';
        if (platform === 'Email') {
            link = `mailto:?subject=${encodeURIComponent((0, isString_1.isStringStrict)(title) ? title : 'Check out this article')}&body=${url}`;
        }
        return {
            type: platform,
            link
        };
    });
};
exports.getShareLinks = getShareLinks;
