"use strict";
/**
 * Utils - Get Taxonomy Info
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTaxonomyInfo = void 0;
const isObject_1 = require("../isObject/isObject");
const isString_1 = require("../isString/isString");
const isBoolean_1 = require("../isBoolean/isBoolean");
const normalizeContentType_1 = require("../normalizeContentType/normalizeContentType");
/**
 * Function - get taxonomy attributes
 *
 * @param {string} contentType
 * @param {import('../../render/renderTypes').RenderItem} pageData
 * @return {import('../../global/globalTypes').Taxonomy}
 */
const getTaxonomyInfo = (contentType, pageData) => {
    const value = {
        id: '',
        slug: '',
        title: '',
        contentType: '',
        useContentTypeSlug: true,
        isPage: false
    };
    const taxObj = contentType === 'taxonomy' ? pageData : pageData?.taxonomy;
    if (!(0, isObject_1.isObjectStrict)(taxObj)) {
        return value;
    }
    const { id, slug, title, contentType: type, useContentTypeSlug, isPage } = taxObj;
    value.id = (0, isString_1.isStringStrict)(id) ? id : '';
    value.slug = (0, isString_1.isStringStrict)(slug) ? slug : '';
    value.title = (0, isString_1.isStringStrict)(title) ? title : '';
    value.contentType = (0, isString_1.isStringStrict)(type) ? (0, normalizeContentType_1.normalizeContentType)(type) : '';
    value.useContentTypeSlug = (0, isBoolean_1.isBoolean)(useContentTypeSlug) ? useContentTypeSlug : true;
    value.isPage = (0, isBoolean_1.isBoolean)(isPage) ? isPage : false;
    return value;
};
exports.getTaxonomyInfo = getTaxonomyInfo;
