"use strict";
/**
 * Utils - Resolve Internal Links
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveInternalLinks = void 0;
/* Imports */
const isArray_1 = require("../isArray/isArray");
const isString_1 = require("../isString/isString");
const isObject_1 = require("../isObject/isObject");
const getObjectKeys_1 = require("../getObjectKeys/getObjectKeys");
const isFunction_1 = require("../isFunction/isFunction");
/**
 * Function - recursively set internal props from outer data
 *
 * @param {object} data
 * @param {object} currentData
 * @param {string[]} [props]
 * @param {function} [filterValue]
 * @return {void}
 */
const resolveInternalLinks = (data, currentData, props = ['internalLink'], filterValue) => {
    if (!(0, isObject_1.isObject)(data) || !(0, isObject_1.isObject)(currentData) || !(0, isArray_1.isArray)(props)) {
        return;
    }
    (0, getObjectKeys_1.getObjectKeys)(currentData).forEach((prop) => {
        const value = currentData[prop];
        if (props.includes(prop.toString())) {
            let v;
            if ((0, isArray_1.isArray)(value)) {
                v = value.map((k) => data[k]);
            }
            if ((0, isString_1.isString)(value)) {
                v = data[value];
            }
            if ((0, isFunction_1.isFunction)(filterValue)) {
                v = filterValue(prop, v);
            }
            currentData[prop] = v;
        }
        else if ((0, isObject_1.isObject)(value)) {
            resolveInternalLinks(data, value, props, filterValue);
        }
    });
};
exports.resolveInternalLinks = resolveInternalLinks;
