"use strict";
/**
 * Utils - Tag
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.tagExists = exports.getTag = void 0;
const isObject_1 = require("../isObject/isObject");
const isString_1 = require("../isString/isString");
const isArray_1 = require("../isArray/isArray");
/**
 * Function - get data from metadata object
 *
 * @type {import('./tagTypes').TagGet}
 */
const getTag = (obj, id) => {
    if (!(0, isObject_1.isObjectStrict)(obj) || !(0, isString_1.isStringStrict)(id)) {
        return;
    }
    const tags = obj.metadata?.tags;
    if (!(0, isArray_1.isArrayStrict)(tags)) {
        return;
    }
    let tagInfo;
    tags.find((tag) => {
        if (!(0, isObject_1.isObjectStrict)(tag)) {
            return false;
        }
        const tagId = tag.id;
        if (tagId === id) {
            tagInfo = {
                id: tagId,
                name: (0, isString_1.isStringStrict)(tag.name) ? tag.name : ''
            };
            return true;
        }
        return false;
    });
    return tagInfo;
};
exports.getTag = getTag;
/**
 * Function - check if tag exists in metadata object
 *
 * @type {import('./tagTypes').TagExists}
 */
const tagExists = (obj, id) => {
    const res = getTag(obj, id);
    return res !== undefined;
};
exports.tagExists = tagExists;
