"use strict";
/**
 * Layouts - Column
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Column = void 0;
const filters_1 = require("../../utils/filters/filters");
const isString_1 = require("../../utils/isString/isString");
const isObject_1 = require("../../utils/isObject/isObject");
/**
 * Function - output column wrapper
 *
 * @param {import('./ColumnTypes').ColumnProps} props
 * @return {Promise<import('./ColumnTypes').ColumnReturn>}
 */
const Column = async (props) => {
    /* Fallback output */
    const fallback = {
        start: '',
        end: ''
    };
    /* Props must be object */
    if (!(0, isObject_1.isObjectStrict)(props)) {
        return fallback;
    }
    props = await (0, filters_1.applyFilters)('columnProps', props, { renderType: 'column' });
    /* Filtered props must be object */
    if (!(0, isObject_1.isObjectStrict)(props)) {
        return fallback;
    }
    const { args } = props;
    const { tag = 'div', width = '', widthSmall = '', widthMedium = '', widthLarge = '', widthCustom = null, justify = '', align = '', classes = '', style = '', attr = '' } = (0, isObject_1.isObjectStrict)(args) ? args : {};
    /* Classes */
    const classesArr = [];
    if ((0, isString_1.isStringStrict)(classes)) {
        classesArr.push(classes);
    }
    /* Width */
    if ((0, isString_1.isStringStrict)(width)) {
        classesArr.push(width);
    }
    if ((0, isString_1.isStringStrict)(widthSmall) && widthSmall !== width) {
        classesArr.push(widthSmall);
    }
    if ((0, isString_1.isStringStrict)(widthMedium) && widthMedium !== widthSmall) {
        classesArr.push(widthMedium);
    }
    if ((0, isString_1.isStringStrict)(widthLarge) && widthLarge !== widthMedium) {
        classesArr.push(widthLarge);
    }
    /* Justify */
    if ((0, isString_1.isStringStrict)(justify)) {
        classesArr.push(justify);
    }
    /* Align */
    if ((0, isString_1.isStringStrict)(align)) {
        classesArr.push(align);
    }
    /* Style */
    const stylesArr = [];
    if ((0, isString_1.isStringStrict)(style)) {
        stylesArr.push(style);
    }
    if ((0, isObject_1.isObjectStrict)(widthCustom)) {
        if ((0, isString_1.isStringStrict)(widthCustom.class)) {
            classesArr.push(widthCustom.class);
        }
        const styleArr = [
            `--width:${(0, isString_1.isStringStrict)(widthCustom.default) ? widthCustom.default : '100%'}`,
            `--width-small:${(0, isString_1.isStringStrict)(widthCustom.small) ? widthCustom.small : '100%'}`,
            `--width-medium:${(0, isString_1.isStringStrict)(widthCustom.medium) ? widthCustom.medium : '100%'}`,
            `--width-large:${(0, isString_1.isStringStrict)(widthCustom.large) ? widthCustom.large : '100%'}`
        ];
        stylesArr.push(styleArr.join(';'));
    }
    const styles = (stylesArr.length > 0) ? ` style="${stylesArr.join(';')}"` : '';
    /* Attributes */
    let attrs = '';
    if ((0, isString_1.isStringStrict)(attr)) {
        attrs = ` ${attr}`;
    }
    if (classesArr.length > 0) {
        attrs += ` class="${classesArr.join(' ')}"`;
    }
    /* Output */
    return {
        start: `<${tag}${attrs}${styles}>`,
        end: `</${tag}>`
    };
};
exports.Column = Column;
