/**
 * Render
 */
import type { RenderContentArgs, RenderItemArgs, RenderItemReturn, RenderArgs, RenderReturn } from './renderTypes';
import type { GenericFunctions, HtmlString } from '../global/globalTypes';
/**
 * Function - get config and formation render functions
 *
 * @return {import('../global/globalTypes').GenericFunctions}
 */
declare const getRenderFunctions: () => GenericFunctions;
/**
 * Function - recurse and output nested content
 *
 * @param {import('./RenderTypes').RenderContentArgs} args
 * @param {import('../global/globalTypes').HtmlString} [_output]
 * @return {Promise<string>}
 */
declare const renderContent: (args: RenderContentArgs, _output?: HtmlString) => Promise<string>;
/**
 * Function - output single post or page
 *
 * @param {import('./RenderTypes').RenderItemArgs} args
 * @return {import('./RenderTypes').RenderItemReturn}
 */
declare const renderItem: (args: RenderItemArgs) => Promise<RenderItemReturn>;
/**
 * Function - loop through all content types to output pages and posts
 *
 * @param {import('./RenderTypes').RenderArgs} args
 * @return {Promise<import('./RenderTypes').RenderReturn[]|import('./RenderTypes').RenderReturn>}
 */
declare const render: (args: RenderArgs) => Promise<RenderReturn[] | RenderReturn>;
export { render, renderItem, renderContent, getRenderFunctions };
