"use strict";
/**
 * Render - Inline
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderInlineItem = exports.renderInlineContent = void 0;
const render_1 = require("./render");
const isObject_1 = require("../utils/isObject/isObject");
const isString_1 = require("../utils/isString/isString");
/**
 * Function - convenience wrapper for render content
 *
 * @param {import('./renderTypes').RenderItem[]} items
 * @return {Promise<string>}
 */
const renderInlineContent = async (items) => {
    return await (0, render_1.renderContent)({
        content: items,
        parents: [],
        pageData: {},
        pageContains: [],
        pageHeadings: [],
        navigations: {},
        renderFunctions: (0, render_1.getRenderFunctions)()
    });
};
exports.renderInlineContent = renderInlineContent;
/**
 * Function - convenience wrapper for render item
 *
 * @param {import('./renderTypes').RenderInlineItemArgs} args
 * @return {Promise<string>}
 */
const renderInlineItem = async (args) => {
    if (!(0, isObject_1.isObjectStrict)(args)) {
        return '';
    }
    const { contentType } = args;
    const res = await (0, render_1.renderItem)({
        item: args,
        contentType,
        renderFunctions: (0, render_1.getRenderFunctions)()
    });
    if ((0, isString_1.isString)(res?.data?.output)) {
        return res.data.output;
    }
    return '';
};
exports.renderInlineItem = renderInlineItem;
