"use strict";
/**
 * Serverless - Preview
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Preview = void 0;
const config_1 = require("../../config/config");
const getAllContentfulData_1 = require("../../utils/getAllContentfulData/getAllContentfulData");
const isObject_1 = require("../../utils/isObject/isObject");
const isString_1 = require("../../utils/isString/isString");
const filters_1 = require("../../utils/filters/filters");
const actions_1 = require("../../utils/actions/actions");
const shortcodes_1 = require("../../utils/shortcodes/shortcodes");
const render_1 = require("../../render/render");
/**
 * Function - output preview from contentful
 *
 * @param {import('./PreviewTypes').PreviewArgs} args
 * @return {Promise<Response>} Response
 */
const Preview = async ({ request, next, env, siteConfig }) => {
    /* Params */
    const { searchParams } = new URL(request.url);
    const contentType = searchParams.get('content_type');
    const id = searchParams.get('preview');
    /* Preview id and content type required */
    if (!(0, isString_1.isStringStrict)(id) || !(0, isString_1.isStringStrict)(contentType)) {
        return next();
    }
    /* Config */
    (0, config_1.setConfig)(siteConfig);
    await (0, config_1.setConfigFilter)(env);
    (0, filters_1.setFilters)(siteConfig.filters);
    (0, actions_1.setActions)(siteConfig.actions);
    (0, shortcodes_1.setShortcodes)(siteConfig.shortcodes);
    /* Data params */
    const previewData = { id, contentType };
    /* Output */
    const data = await (0, render_1.render)({
        previewData,
        allData: await (0, getAllContentfulData_1.getAllContentfulData)({
            previewData
        })
    });
    let html = '';
    if ((0, isObject_1.isObjectStrict)(data)) {
        html = data.output !== undefined ? data.output : '';
    }
    return new Response(html, {
        status: 200,
        headers: {
            'Content-Type': 'text/html;charset=UTF-8'
        }
    });
};
exports.Preview = Preview;
