"use strict";
/**
 * Serverless - Reload
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Reload = void 0;
const config_1 = require("../../config/config");
const getAllContentfulData_1 = require("../../utils/getAllContentfulData/getAllContentfulData");
const isObject_1 = require("../../utils/isObject/isObject");
const isString_1 = require("../../utils/isString/isString");
const isNumber_1 = require("../../utils/isNumber/isNumber");
const isFunction_1 = require("../../utils/isFunction/isFunction");
const filters_1 = require("../../utils/filters/filters");
const actions_1 = require("../../utils/actions/actions");
const shortcodes_1 = require("../../utils/shortcodes/shortcodes");
const render_1 = require("../../render/render");
/**
 * Function - output paginated and/or filtered page on browser reload
 *
 * @param {import('./ReloadTypes').ReloadArgs} args
 * @return {Promise<Response>} Response
 */
const Reload = async ({ request, next, env, siteConfig }) => {
    try {
        /* Query */
        const { searchParams, pathname } = new URL(request.url);
        const page = searchParams.get('page');
        const filters = searchParams.get('filters');
        const path = pathname;
        const query = {};
        let noPage = false;
        let noFilters = false;
        if ((0, isString_1.isStringStrict)(page)) {
            query.page = page;
        }
        else {
            noPage = true;
        }
        if ((0, isString_1.isStringStrict)(filters)) {
            query.filters = filters;
        }
        else {
            noFilters = true;
        }
        /* No query move on to default page */
        if (noPage || noFilters) {
            return next();
        }
        /* Config */
        (0, config_1.setConfig)(siteConfig);
        await (0, config_1.setConfigFilter)(env);
        (0, filters_1.setFilters)(siteConfig.filters);
        (0, actions_1.setActions)(siteConfig.actions);
        (0, shortcodes_1.setShortcodes)(siteConfig.shortcodes);
        /* Data params */
        const serverlessData = { query, path };
        /* Output */
        const data = await (0, render_1.render)({
            serverlessData,
            allData: await (0, getAllContentfulData_1.getAllContentfulData)({
                serverlessData
            })
        });
        let html = '';
        if ((0, isObject_1.isObjectStrict)(data)) {
            html = data.output !== undefined ? data.output : '';
        }
        return new Response(html, {
            status: 200,
            headers: {
                'Content-Type': 'text/html;charset=UTF-8'
            }
        });
    }
    catch (error) {
        console.error(config_1.config.console.red, '[SSF] Error with reload function: ', error);
        let statusCode = 500;
        if ((0, isObject_1.isObjectStrict)(error)) {
            const err = error;
            if ((0, isNumber_1.isNumber)(err.httpStatusCode)) {
                statusCode = err.httpStatusCode;
            }
        }
        let html = '';
        if ((0, isFunction_1.isFunction)(config_1.config.renderFunctions.httpError)) {
            html = await config_1.config.renderFunctions.httpError(statusCode);
        }
        return new Response(html, {
            status: statusCode,
            headers: {
                'Content-Type': 'text/html;charset=UTF-8'
            }
        });
    }
};
exports.Reload = Reload;
