/**
 * Utils - Actions
 */
import type { Actions } from './actionsTypes';
/**
 * Function - add action to action object
 *
 * @param {string} name
 * @param {function} action
 * @return {boolean}
 */
declare const addAction: <T extends keyof Actions>(name: T, action: Actions[T]) => boolean;
/**
 * Function - remove action from actions object
 *
 * @param {string} name
 * @param {function} action
 * @return {boolean}
 */
declare const removeAction: <T extends keyof Actions>(name: T, action: Actions[T]) => boolean;
/**
 * Function - run callback functions from actions object
 *
 * @param {string} name
 * @param {*} [args]
 * @return {Promise<void>}
 */
declare const doActions: <T>(name: string, args?: T) => Promise<void>;
/**
 * Function - empty actions object
 *
 * @return {void}
 */
declare const resetActions: () => void;
/**
 * Function - fill actions object
 *
 * @param {import('./actionsTypes').Actions} args
 * @return {boolean}
 */
declare const setActions: (args: Partial<Actions>) => boolean;
export { addAction, removeAction, doActions, resetActions, setActions };
