"use strict";
/**
 * Utils - Get Archive Info
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getArchiveInfo = void 0;
const config_1 = require("../../config/config");
const isObject_1 = require("../isObject/isObject");
const isString_1 = require("../isString/isString");
const normalizeContentType_1 = require("../normalizeContentType/normalizeContentType");
/**
 * Function - get archive id, slug and title
 *
 * @param {string} contentType
 * @return {import('./getArchiveInfoTypes').ArchiveInfo}
 */
const getArchiveInfo = (contentType = '') => {
    const value = {
        id: '',
        slug: '',
        title: ''
    };
    contentType = (0, normalizeContentType_1.normalizeContentType)(contentType);
    if (contentType === 'page') {
        return value;
    }
    const info = config_1.config.archiveMeta[contentType];
    if (!(0, isObject_1.isObjectStrict)(info)) {
        return value;
    }
    const { id, slug, title } = info;
    value.id = (0, isString_1.isStringStrict)(id) ? id : '';
    value.slug = (0, isString_1.isStringStrict)(slug) ? slug : '';
    value.title = (0, isString_1.isStringStrict)(title) ? title : '';
    return value;
};
exports.getArchiveInfo = getArchiveInfo;
