"use strict";
/**
 * Utils - Get Archive Link
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getArchiveLink = void 0;
const config_1 = require("../../config/config");
const normalizeContentType_1 = require("../normalizeContentType/normalizeContentType");
const isString_1 = require("../isString/isString");
const getArchiveInfo_1 = require("../getArchiveInfo/getArchiveInfo");
const getTaxonomyInfo_1 = require("../getTaxonomyInfo/getTaxonomyInfo");
const getPermalink_1 = require("../getPermalink/getPermalink");
const getSlug_1 = require("../getSlug/getSlug");
/**
 * Function - get archive link by content type or taxonomy
 *
 * @param {string} contentType
 * @param {import('../../render/renderTypes').RenderItem} [pageData]
 * @return {import('./getArchiveLinkTypes').ArchiveLinkReturn}
 */
const getArchiveLink = (contentType = '', pageData) => {
    /* Defaults */
    let title = '';
    let slug;
    /* Normalize */
    contentType = (0, normalizeContentType_1.normalizeContentType)(contentType);
    /* Taxonomy */
    const taxonomyInfo = (0, getTaxonomyInfo_1.getTaxonomyInfo)(contentType, pageData);
    const { title: taxonomyTitle, isPage: taxonomyIsPage, contentType: taxonomyType, useContentTypeSlug: taxonomyUseTypeSlug } = taxonomyInfo;
    if (contentType === 'term' && taxonomyIsPage) {
        slug = (0, getSlug_1.getSlug)({
            slug: '',
            contentType,
            pageData
        });
        title = taxonomyTitle;
    }
    const useArchiveType = taxonomyUseTypeSlug && taxonomyType !== '';
    if (contentType === 'taxonomy' && useArchiveType) {
        contentType = taxonomyType;
    }
    if (contentType === 'term' && !taxonomyIsPage && useArchiveType) {
        contentType = taxonomyType;
    }
    /* Archive */
    const archiveInfo = (0, getArchiveInfo_1.getArchiveInfo)(contentType);
    const { id: archiveId, slug: archiveSlug, title: archiveTitle } = archiveInfo;
    if (archiveSlug !== '' && archiveId !== '') {
        slug = (0, getSlug_1.getSlug)({
            id: archiveId,
            slug: archiveSlug,
            contentType: 'page'
        });
        const plural = config_1.config.archiveMeta[contentType].plural;
        title = (0, isString_1.isStringStrict)(plural) ? plural : archiveTitle;
    }
    /* Output */
    return {
        title,
        link: (0, isString_1.isStringStrict)(slug) ? (0, getPermalink_1.getPermalink)(slug) : ''
    };
};
exports.getArchiveLink = getArchiveLink;
