"use strict";
/**
 * Utils - Write Serverless Files
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeServerlessFiles = void 0;
const promises_1 = require("node:fs/promises");
const node_path_1 = require("node:path");
const getPathDepth_1 = require("../getPathDepth/getPathDepth");
const isObject_1 = require("../isObject/isObject");
const isString_1 = require("../isString/isString");
const config_1 = require("../../config/config");
/**
 * Function - write files from serverless
 *
 * @return {Promise<void>}
 */
const writeServerlessFiles = async (args) => {
    try {
        /* Args */
        const { packageDir = 'lib', configName = 'config', configFile = 'src/config/config.js' } = (0, isObject_1.isObjectStrict)(args) ? args : {};
        /* Package */
        const formationPackage = `@alanizcreative/static-site-formation/${packageDir}/serverless/`;
        /* Serverless folder */
        if ((0, isString_1.isStringStrict)(config_1.config.serverless.dir)) {
            await (0, promises_1.mkdir)((0, node_path_1.resolve)(config_1.config.serverless.dir), { recursive: true });
        }
        /* Ajax file */
        if ((0, isString_1.isStringStrict)(config_1.config.serverless.files.ajax)) {
            const content = `import { ${configName} } from '${(0, getPathDepth_1.getPathDepth)(`${config_1.config.serverless.dir}/${config_1.config.serverless.files.ajax}`)}${configFile}'\nimport { Ajax } from '${formationPackage}Ajax/Ajax'\nconst render = async ({ request, env }) => { return await Ajax({ request, env, siteConfig: ${configName} }) }\nexport const onRequestPost = [render]\n`;
            const path = (0, node_path_1.resolve)(config_1.config.serverless.dir, config_1.config.serverless.files.ajax);
            const dir = (0, node_path_1.dirname)(path);
            await (0, promises_1.mkdir)((0, node_path_1.resolve)(config_1.config.serverless.dir, dir), { recursive: true });
            await (0, promises_1.writeFile)(path, content);
            console.info(config_1.config.console.green, `[SSF] Successfully wrote ${path}`);
        }
        /* Preview file */
        if (config_1.config.env.dev && (0, isString_1.isStringStrict)(config_1.config.serverless.files.preview)) {
            const content = `import { ${configName} } from '${(0, getPathDepth_1.getPathDepth)(`${config_1.config.serverless.dir}/${config_1.config.serverless.files.preview}`)}${configFile}'\nimport { Preview } from '${formationPackage}Preview/Preview'\nconst render = async ({ request, next, env }) => { return await Preview({ request, next, env, siteConfig: ${configName} }) }\nexport const onRequestGet = [render]\n`;
            const path = (0, node_path_1.resolve)(config_1.config.serverless.dir, config_1.config.serverless.files.preview);
            const dir = (0, node_path_1.dirname)(path);
            await (0, promises_1.mkdir)((0, node_path_1.resolve)(config_1.config.serverless.dir, dir), { recursive: true });
            await (0, promises_1.writeFile)(path, content);
            console.info(config_1.config.console.green, `[SSF] Successfully wrote ${path}`);
        }
        /* Routes */
        const routes = Object.keys(config_1.config.serverless.routes);
        if (routes.length > 0) {
            const reloadFile = config_1.config.serverless.files.reload;
            for (let i = 0; i < routes.length; i += 1) {
                const type = routes[i];
                const routesArr = config_1.config.serverless.routes[type];
                for (let r = 0; r < routesArr.length; r += 1) {
                    let { path = '', content = '' } = routesArr[r];
                    if (type === 'reload' && (0, isString_1.isStringStrict)(reloadFile) && (0, isString_1.isStringStrict)(path)) {
                        path = `${path}/${reloadFile}`;
                        content = `import { ${configName} } from '${(0, getPathDepth_1.getPathDepth)(`${config_1.config.serverless.dir}/${path}`)}${configFile}'\nimport { Reload } from '${formationPackage}Reload/Reload'\nconst render = async ({ request, next, env }) => { return await Reload({ request, next, env, siteConfig: ${configName} }) }\nexport const onRequestGet = [render]\n`;
                    }
                    if ((0, isString_1.isStringStrict)(path) && (0, isString_1.isStringStrict)(content)) {
                        path = (0, node_path_1.resolve)(config_1.config.serverless.dir, path);
                        const dir = (0, node_path_1.dirname)(path);
                        await (0, promises_1.mkdir)((0, node_path_1.resolve)(config_1.config.serverless.dir, dir), { recursive: true });
                        await (0, promises_1.writeFile)(path, content);
                        console.info(config_1.config.console.green, `[SSF] Successfully wrote ${path}`);
                    }
                }
            }
        }
    }
    catch (error) {
        console.error(config_1.config.console.red, '[SSF] Error writing serverless files: ', error);
    }
};
exports.writeServerlessFiles = writeServerlessFiles;
