"use strict";
/**
 * Utils - Write Store Files
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeStoreFiles = void 0;
/* Imports */
const promises_1 = require("node:fs/promises");
const node_path_1 = require("node:path");
const config_1 = require("../../config/config");
/**
 * Function - write files from config store object
 *
 * @return {Promise<void>}
 */
const writeStoreFiles = async () => {
    try {
        const files = config_1.config.store.files;
        const fileKeys = Object.keys(files);
        await (0, promises_1.mkdir)((0, node_path_1.resolve)(config_1.config.store.dir), { recursive: true });
        if (fileKeys.length > 0) {
            for (let i = 0; i < fileKeys.length; i += 1) {
                const file = files[fileKeys[i]];
                const path = (0, node_path_1.resolve)(config_1.config.store.dir, file.name);
                await (0, promises_1.writeFile)(path, file.data);
                console.info(config_1.config.console.green, `[SSF] Successfully wrote ${path}`);
            }
        }
    }
    catch (error) {
        console.error(config_1.config.console.red, '[SSF] Error writing store files: ', error);
    }
};
exports.writeStoreFiles = writeStoreFiles;
