/**
 * Components - Navigation
 */
import type { NavigationProps, Navigation as Navigations, NavigationItem, NavigationBreadcrumbItem, NavigationOutputArgs, NavigationBreadcrumbOutputArgs } from './NavigationTypes';
/**
 * Class - recursively generate navigation output
 */
declare class Navigation {
    #private;
    /**
     * Store all navigations
     *
     * @type {import('./NavigationTypes').Navigations[]}
     */
    navigations: Navigations[];
    /**
     * Store all navigation items
     *
     * @type {import('./NavigationTypes').NavigationItem[]}
     */
    items: NavigationItem[];
    /**
     * Current link to compare against
     *
     * @type {string}
     */
    currentLink: string;
    /**
     * Current content type to compare against
     *
     * @type {string}
     */
    currentType: string;
    /**
     * Store initialize success
     *
     * @type {boolean}
     */
    init: boolean;
    /**
     * Set properties and initialize
     *
     * @param {import('./NavigationTypes').NavigationProps} props
     */
    constructor(props: NavigationProps);
    /**
     * Return navigation html output
     *
     * @param {string} location
     * @param {import('./NavigationTypes').NavigationOutputArgs} args
     * @param {number} maxDepth
     * @return {string} HTML - ul
     */
    getOutput(location: string | undefined, args: NavigationOutputArgs, maxDepth?: number): string;
    /**
     * Return breadcrumbs html output
     *
     * @param {import('./NavigationTypes').NavigationBreadcrumbItem[]} items
     * @param {import('./NavigationTypes').NavigationBreadcrumbOutputArgs} args
     * @param {string} current
     * @return {string} HTML - ol
     */
    getBreadcrumbs(items: NavigationBreadcrumbItem[] | undefined, args: NavigationBreadcrumbOutputArgs, current?: string): string;
}
export { Navigation };
